ProtocolError

Enum ProtocolError 

#[non_exhaustive]
pub enum ProtocolError {
Show 14 variants BufferUnderflow { expected: usize, got: usize, }, UnknownTypeCode(u8), UnexpectedNull, InvalidUtf8(FromUtf8Error), HandshakeFailed { server_major: i16, server_minor: i16, server_patch: i16, message: String, }, ServerError { status: i32, message: String, }, DecimalError(String), CompactFooterNeedsSchema, MalformedBinaryObject(String), RecursionLimitExceeded, MalformedResponse(String), TypeMismatch { expected: &'static str, got: &'static str, }, BinaryTypeNotRegistered(i32), SchemaNotFound { type_id: i32, schema_id: i32, },
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


BufferUnderflow

Fields

expected: usize
got: usize


UnknownTypeCode(u8)



UnexpectedNull



InvalidUtf8(FromUtf8Error)



HandshakeFailed

Fields

server_major: i16
server_minor: i16
server_patch: i16
message: String


ServerError

Fields

status: i32
message: String


DecimalError(String)



CompactFooterNeedsSchema



MalformedBinaryObject(String)



RecursionLimitExceeded



MalformedResponse(String)



TypeMismatch

Fields

expected: &'static str
got: &'static str


BinaryTypeNotRegistered(i32)

No metadata is registered on the cluster for a type id encountered while decoding a compact-footer binary object — the schema’s field ids can’t be recovered without it.



SchemaNotFound

Metadata was found for the type, but none of its registered schemas matches the schema_id stamped in the object’s header.

Fields

type_id: i32
schema_id: i32