Crate ignite_client

Crate ignite_client 

Re-exports

pub use cache::IgniteCache;
pub use client::IgniteClient;
pub use error::IgniteError;
pub use error::Result;
pub use pool::IgniteClientConfig;
pub use query::Column;
pub use query::QueryResult;
pub use query::Row;
pub use query::UpdateResult;
pub use stream::QueryStream;
pub use transaction::Transaction;

Modules

affinity
Partition awareness / affinity routing.
cache
client
discovery
Server endpoint discovery — a port of Java ClientClusterDiscovery.
error
pool
query
stream
transaction

Structs

ExpiryPolicy
Per-entry lifetime policy: the time-to-live applied when an entry is created, updated, and accessed. Attach it to a cache handle with crate::IgniteCache::with_expiry_policy.

Enums

ColumnType
The SQL type of a value returned by Ignite, inferred from the 1-byte wire type-tag that accompanies each encoded value.
ExpiryDuration
Lifetime applied to a cache entry by an ExpiryPolicy for one event (creation, update, or access).
IgniteValue
Rust representation of a typed Ignite binary value.
ProtocolError
StatementType
TxConcurrency
TxIsolation

Functions

cache_id
Cache ID is the Java hash of the upper-cased cache name.
java_hash
Replicates Java’s String.hashCode(). Used to compute type IDs and field IDs in the Binary Object format.